# Industrial Data Science Workflow
## Full workflow for ETL, statistics, and Machine learning modelling of (usually) time-stamped industrial facilities data.

Authors:
- Marco César Prado Soares, Data Science Specialist at Bayer (Crop Science)
  - marcosoares.feq@gmail.com

- Gabriel Fernandes Luz
  - gfluz94@gmail.com

- Use the notebooks in https://github.com/marcosoares-92/IndustrialDataScienceWorkflow/tree/idsw_etl to check how to use this package.